| Title: | Perform Inference on Summaries of Longitudinal Algorithm-Agnostic Variable Importance |
|---|---|
| Description: | Calculate point estimates of and valid confidence intervals for longitudinal summaries of nonparametric, algorithm-agnostic variable importance measures. For more details, see Williamson et al. (2024) <doi:10.48550/arXiv.2311.01638>. |
| Authors: | Brian D. Williamson [aut, cre] (ORCID: <https://orcid.org/0000-0002-7024-548X>) |
| Maintainer: | Brian D. Williamson <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 1.0.0 |
| Built: | 2026-05-18 18:19:53 UTC |
| Source: | https://github.com/bdwilliamson/lvimp |
lvim objectFormat a lvim object
## S3 method for class 'lvim' format(x, digits = 3, ...)## S3 method for class 'lvim' format(x, digits = 3, ...)
x |
the |
digits |
the number of digits to format to |
... |
other options, see the generic |
A formatted lvim object for printing.
Create a longitudinal variable importance object from several constituent cross-sectional variable importance objects.
lvim(vim_list = list(), timepoints = numeric())lvim(vim_list = list(), timepoints = numeric())
vim_list |
a list of individual, cross-sectional variable importance objects. Assumed to be in order over time. |
timepoints |
a numeric vector of timepoints of interest |
an object of class lvim
Compute a nonparametric estimate of (and efficient influence function for) the area under the longitudinal variable importance trajectory (AUTC) over a contiguous subset of the time series.
lvim_autc( lvim, indices = 1:length(lvim), interpolator = "linear", delta = 0, ... )lvim_autc( lvim, indices = 1:length(lvim), interpolator = "linear", delta = 0, ... )
lvim |
an object of class |
indices |
a numeric vector indicating the contiguous subset of the time series |
interpolator |
a string indicating the type of interpolator used to take the area under the trajectory |
delta |
null hypothesis value |
... |
other arguments to be passed to the interpolator function |
The lvim object, with point estimates, CIs, and p-values
related to the area under the trend in variable importance filled in.
Compute a nonparametric estimate of (and efficient influence function for) the average longitudinal variable importance over a contiguous subset of the time series.
lvim_average(lvim, indices = 1:length(lvim), delta = 0)lvim_average(lvim, indices = 1:length(lvim), delta = 0)
lvim |
an object of class |
indices |
a numeric vector indicating the contiguous subset of the time series |
delta |
null hypothesis value |
The lvim object, with point estimates, CIs, and p-values
related to the average variable importance filled in.
Compute a nonparametric estimate of (and efficient influence function for) the linear trend in the longitudinal variable importance over a contiguous subset of the time series.
lvim_trend(lvim, indices = 1:length(lvim), delta = 0)lvim_trend(lvim, indices = 1:length(lvim), delta = 0)
lvim |
an object of class |
indices |
a numeric vector indicating the contiguous subset of the time series |
delta |
null hypothesis value |
The lvim object, with point estimates, CIs, and p-values
related to the linear trend in variable importance filled in.
lvim objectPrint a lvim object
## S3 method for class 'lvim' print(x, ...)## S3 method for class 'lvim' print(x, ...)
x |
the |
... |
other options, see the generic |
No return value, called for side effects.